#
# spec file for package rsvndump
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rsvndump
Version:        0.6.2
Release:        1.5
Summary:        Remote Subversion Repository Dumping Tool
License:        GPL-3.0-only
Group:          Development/Tools/Version Control
URL:            https://rsvndump.sourceforge.net/
Source:         http://prdownloads.sourceforge.net/rsvndump/rsvndump-%{version}.tar.gz
BuildRequires:  libtool
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(apr-1)
BuildRequires:  pkgconfig(apr-util-1)
BuildRequires:  pkgconfig(libsvn_delta)
BuildRequires:  pkgconfig(libsvn_fs)
BuildRequires:  pkgconfig(libsvn_ra)
BuildRequires:  pkgconfig(libsvn_subr)

%description
rsvndump is a command line tool that is able to dump a subversion
repository that resides on a remote server. All data is dumped in the
format that can be read/written by svnadmin, so the data produced by
rsvndump can easily be imported into a new subversion repository.

%lang_package

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install
%find_lang rsvndump

%check
%make_build check

%files
%license COPYING
%doc AUTHORS ChangeLog README
%{_bindir}/rsvndump

%files lang -f %{name}.lang
%license COPYING

%changelog
* Sun Nov 12 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.6.2:
  * fix an edge-case where delete actions would be issued for
    non-existent paths, resulting in unloadable dumps
* Sun Dec  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.6.1:
  * fix a bug where sub-directories with matching prefixes would be
    included in the dump
- drop rsvndump-fix_linking_order.patch
* Tue Dec 10 2019 Martin Pluskal <mpluskal@suse.com>
- Cleanup and modernise spec file
* Wed May 16 2012 pascal.bleser@opensuse.org
- update to 0.6:
  * the version path and property storages have been redesigned, resulting in a
    notable speedup for certain use cases
  * an issue that could have led to unloadable dumps when dumping
    subdirectories has been resolved
* Thu Mar 15 2012 pascal.bleser@opensuse.org
- update to 0.5.8:
  * fixes bug which occurred when directories were copied that were once
    created by a replace option
  * fixes bug which occurred during copy operations that also involved
    modifications on subdirectories in a single revision
* Mon Nov 21 2011 pascal.bleser@opensuse.org
- add patch to fix linking order on >= 12.1
- update to 0.5.7:
  * fixes possibly invalid dump output when run with --keep-revnums
  * the --dry-run and --obfuscate command line flags have been added to ease
    the submission of dumps for bug reports
* Thu Jul 21 2011 pascal.bleser@opensuse.org
- update to 0.5.6:
  * performance improvements for revision range determination and path hash
    calculations
  * a bug that could cause unloadable dumps under certain conditions as well as
    a possible segmentation fault have been fixed
* Thu Mar  3 2011 pascal.bleser@opensuse.org
- update to 0.5.5:
  * fixes a bug introduced in 0.5.3 that could lead to crashes when dumping a
    subdirectory
  * fixes performance issues caused by unnecessary stats for copied revisions
* Sun Feb 13 2011 pascal.bleser@opensuse.org
- update to 0.5.4:
  * add support for svn's --config-dir option
  * fixed missing deltification when running with --deltas
  * fixed crash when passing certain command line options multiple times
* Sat Mar 13 2010 pascal.bleser@opensuse.org
- update to 0.5.3:
  * added detection for paths affected by a copy operation, which fixes
    possibly invalid dumpfiles (sf#22898487)
  * moved data output to the end of the delta editor run; fixes a bug that
    could prevent properties from being dumped (sf#2898815)
  * fixed dumping of root node modifications
  * fixed missing construction of user prefix when dumping a subdirectory with
  - -keep-revnums
  * fixed --disable-man and --disable-tests arguments for configure
    (sf#2831432)
* Fri Jul 17 2009 pascal.bleser@opensuse.org
- update to 0.5.2:
  * fixes possibly wrong Node-copyfrom-rev revision numbers
  * fixes a possible segmentation fault that occurred when dumping in
    incremental mode and starting at revision 1
* Sun Jul 12 2009 pascal.bleser@opensuse.org
- update to 0.5.1
* Thu Apr 16 2009 pascal.bleser@opensuse.org
- update to 0.4.4-1, fixes building against SVN 1.6
* Tue Mar 31 2009 pascal.bleser@opensuse.org
- update to 0.4.4:
  * minor feature enhancements
* Fri Nov 21 2008 guru@unixtech.be
- update to 0.4.3:
  * new features and bugfixes
  * the command line option --dump-uuid has been added, which includes the
    uuid of a repository in the dump
  * a bug which could occur when dumping a sub-directory via a file:// URL has
    been fixed
* Wed Oct  8 2008 guru@unixtech.be
- update to 0.4.2:
  * fix a segmentation fault that could occur when using --keep-revnums
* Sun Oct  5 2008 guru@unixtech.be
- new package, version 0.4.1:
  * added --keep-revnums flag to sync revision numbers with the source
    repository
  * automatically switch to online mode for file://-urls
  * fixed bug that prevented switching to online mode when dumping a single
    file and using little or less verbosity
